local toc, data = ...
local id = toc.identifier

local gadgetIndex = 0
local Trinkets = {}

local iconAlpha = 70
local cdAlpha = 80
local cdFontSize = 32
local iconSize = 49

local iconImgSize = 48
local iconBrdrSize = 64

local borderImage = wyk.vars.Images.borders.gray.file
local borderAir = wyk.vars.Images.borders.air.file
local borderEarth = wyk.vars.Images.borders.earth.file
local borderDeath = wyk.vars.Images.borders.death.file
local borderLife = wyk.vars.Images.borders.life.file
local borderFire = wyk.vars.Images.borders.fire.file
local borderWater = wyk.vars.Images.borders.water.file
local borderClickable = borderFire
local trinketImage = wyk.vars.Images.slots.trinket.file

function round (x)
  if x >= 0 then
    return math.floor (x + 0.5)
  end  -- if positive

  return math.ceil (x - 0.5)
end

local tLast = 0
local tBuffer  = 0.75

local function CheckTrinket()
    if (Inspect.Time.Frame() - tLast) < tBuffer then return end
    tLast = Inspect.Time.Frame()
    local slot = Utility.Item.Slot.Equipment("trinket")
    local item = Inspect.Item.Detail(slot)
    if item then
        for idx, gadget in pairs(Trinkets) do
            gadget:SetAlpha(iconAlpha)
            gadget.icon:SetAlpha(iconAlpha)
            gadget.icon:SetTexture("Rift", item.icon)
            if item.cooldown == nil then
                gadget.cooldown:SetAlpha(0)
                gadget:SetTexture("libWykkyd", borderImage)
            else
                gadget.cooldown:SetAlpha(1)
                gadget:SetTexture("libWykkyd", borderClickable)
                gadget.cooldown:SetFontColor( .75, .1, .1, cdAlpha )
                local d = item.cooldownRemaining
                local s = ""
                if d == nil then
                    s = "R"
                else
                    d = round(d)
                    if d >= 361 then s = ":(" end
                    if d > 330 and d < 361 then s = "6m" end
                    if d > 270 and d < 331 then s = "5m" end
                    if d > 210 and d < 271 then s = "4m" end
                    if d > 150 and d < 211 then s = "3m" end
                    if d > 99 and d < 151 then s = "2m" end
                    if s == "" then s = ""..d.."" end
                end
                gadget.cooldown:SetText(s)
            end
        end
    else
        for idx, gadget in pairs(Trinkets) do
            gadget:SetAlpha(iconAlpha)
            gadget.icon:SetAlpha(iconAlpha)
            gadget.icon:SetTexture("libWykkyd", trinketImage)
            gadget:SetTexture("libWykkyd", borderImage)
            gadget.cooldown:SetAlpha(0)
        end
    end
end

local started = false

local function StartUp()
    if started == false then
        CheckTrinket()
        table.insert(Event.System.Update.Begin,{CheckTrinket, "Gadgets_TrinketSpy", "CheckTrinket" })
        started = true
    end
end

table.insert(Event.Unit.Availability.Full, {StartUp, "Gadgets_TrinketSpy", "StartUp"})

local function Create(configuration)
    iconAlpha   = (configuration.iconAlpha / 100)
    iconSize    = (configuration.iconSize / 100)
    cdAlpha     = (configuration.cdAlpha / 100)
    cdFontSize  = configuration.cdFontSize
    iconImgSize = 96 * iconSize
    iconBrdrSize = 128 * iconSize
    
	local tsWrapper = wyk.frame.CreateFrame("wtTrinket", WT.Context)
	tsWrapper:SetWidth(iconBrdrSize)
	tsWrapper:SetHeight(iconBrdrSize)
	tsWrapper:SetBackgroundColor(0,0,0,0.0)
    
    local tsBorder = wyk.frame.CreateTexture("wtTrinket", tsWrapper)
	tsBorder:SetWidth(iconBrdrSize)
	tsBorder:SetHeight(iconBrdrSize)
    tsBorder:SetTexture("libWykkyd", borderImage)
    tsBorder:SetLayer(2)
    
	local tsIcon = wyk.frame.CreateTexture("wtTrinket", tsWrapper)
	tsIcon:SetWidth(iconImgSize)
	tsIcon:SetHeight(iconImgSize)
    tsIcon:SetTexture("libWykkyd", trinketImage)
    tsIcon:SetLayer(4)
    tsBorder.icon = tsIcon
    
	local tsCooldown = wyk.frame.CreateText("wtTrinket", tsWrapper)
	tsCooldown:SetFontSize(cdFontSize)
    tsCooldown:SetLayer(6)
	tsCooldown:SetText("")
	tsCooldown.currText = ""
    tsBorder.cooldown = tsCooldown
    
	tsCooldown:SetPoint("CENTER", tsIcon, "CENTER", 0, 0)
	tsIcon:SetPoint("CENTER", tsBorder, "CENTER", 0, 0)
	tsBorder:SetPoint("TOPCENTER", tsWrapper, "TOPCENTER", 0, 0)
        
	table.insert(Trinkets, tsBorder)

	return tsWrapper
end

local dialog = false

local sldiconAlpha = nil
local sldiconSize = nil
local sldcdAlpha = nil
local sldcdFontSize = nil

local function ConfigDialog(container)
    local configFrame = wyk.frame.CreateFrame("tsConfig", container)
	configFrame:SetPoint("TOPLEFT", container, "TOPLEFT")
	configFrame:SetPoint("BOTTOMRIGHT", container, "BOTTOMRIGHT", 0, -32)
	
	sldiconAlpha = wyk.frame.SlideFrame("iconAlpha", configFrame, 220, {L=1,H=100}, 70, "Icon Opacity %", true)
    sldiconAlpha:SetPoint("TOPCENTER", configFrame, "TOPCENTER", 0, 16)
	
	sldiconSize = wyk.frame.SlideFrame("iconSize", configFrame, 220, {L=1,H=100}, 49, "Icon Scale", true)
    sldiconSize:SetPoint("TOPCENTER", sldiconAlpha, "BOTTOMCENTER", 0, 16)
    
	sldcdAlpha = wyk.frame.SlideFrame("cdAlpha", configFrame, 220, {L=0,H=100}, 80, "Cooldown Opacity %")
    sldcdAlpha:SetPoint("TOPCENTER", sldiconSize, "BOTTOMCENTER", 0, 16)
    
	sldcdFontSize = wyk.frame.SlideFrame("cdFontSize", configFrame, 220, {L=6,H=80}, 32, "Cooldown Font Size")
    sldcdFontSize:SetPoint("TOPCENTER", sldcdAlpha, "BOTTOMCENTER", 0, 16)
end

local function GetConfiguration()
	local config = {
        iconAlpha = sldiconAlpha.slider:GetPosition(),
        cdAlpha = sldcdAlpha.slider:GetPosition(),
        iconSize = sldiconSize.slider:GetPosition(),
        cdFontSize = sldcdFontSize.slider:GetPosition(),
    }
    return config
end

local function SetConfiguration(config)
	sldiconAlpha.slider:SetPosition(config.iconAlpha or 75) 
	sldcdAlpha.slider:SetPosition(config.cdAlpha or 75) 
	sldiconSize.slider:SetPosition(config.iconSize or 75) 
	sldcdFontSize.slider:SetPosition(config.cdFontSize or 75) 
end

WT.Gadget.RegisterFactory("tsWrapper", {
		name="Trinket Spy",
		description="Trinket Spy",
		author=toc.toc.Author,
		version=toc.toc.Version,
		["Create"] = Create,
		["ConfigDialog"] = ConfigDialog,
		["GetConfiguration"] = GetConfiguration, 
		["SetConfiguration"] = SetConfiguration, 
	})
 
 